@@ -130,6 +130,19 @@ class Ghidra(Disassembler):
             ["gradle", "buildGhidra"]
         ]
 
+        no_init_gradle_commit = repo.commit("30628db2d09d7b4ce46368b7522dc315e7b245c5")
+        target_commit = repo.commit(version)
+
+        common_ancestor = repo.merge_base(no_init_gradle_commit, target_commit)
+        if target_commit in common_ancestor:
+            # do nothing
+            pass
+        elif no_init_gradle_commit in common_ancestor:
+            # remove init in gradle command
+            del cmds[0][-1]
+        else:
+            raise Exception("Is {version} a valid commit hash?")
+
         for cmd in cmds:
             logger.info(f"$ {' '.join(cmd)}")
             out, err = run_proc(cmd=cmd, timeout=None, cwd=install_dir)
@@ -578,13 +591,13 @@ class Ghidra(Disassembler):
                 dest_addr = dest.getDestinationAddress().getOffset()
                 flow_type = dest.getFlowType()
                 if flow_type.hasFallthrough():
-                    yield Branch(btype=BranchType.FalseBranch, target=dest_addr)
+                    yield Branch(type=BranchType.FalseBranch, target=dest_addr)
                 elif flow_type.isConditional():
-                    yield Branch(btype=BranchType.TrueBranch, target=dest_addr)
+                    yield Branch(type=BranchType.TrueBranch, target=dest_addr)
                 elif flow_type.isUnConditional():
-                    yield Branch(btype=BranchType.UnconditionalBranch, target=dest_addr)
+                    yield Branch(type=BranchType.UnconditionalBranch, target=dest_addr)
                 elif flow_type.isComputed():
-                    yield Branch(btype=BranchType.IndirectBranch, target=None)
+                    yield Branch(type=BranchType.IndirectBranch, target=None)
 
     def get_bb_instructions(self, bb_addr: int, bb_ctxt: Any, func_ctxt: Any) -> List[Tuple(bytes, str)]:
         '''
